@@ -47,6 +47,7 @@ class Api:
         self.proxies = proxies
         self.rate_limit = RateLimit()
         self.sleep_on_rate_limit = sleep_on_rate_limit
+        self.auth_user_id = None  # Note: use this keep uid for auth user
 
         # just use bearer token
         if bearer_token:
@@ -70,12 +71,25 @@ class Api:
                 resource_owner_secret=access_secret,
             )
             self.rate_limit = RateLimit("user")
+            self.auth_user_id = self.get_uid_from_access_token_key(
+                access_token=access_token
+            )
         # use oauth flow by hand
         elif consumer_key and consumer_secret and oauth_flow:
             pass
         else:
             raise PyTwitterError("Need oauth")
 
+    @staticmethod
+    def get_uid_from_access_token_key(access_token: str):
+        """
+        get uid from access token, ex: 1323843269210460160-xxx
+        :param access_token: Access token
+        :return: uid
+        """
+        uid, _ = access_token.split("-")
+        return uid
+
     def _request(
         self, url, verb="GET", params=None, data=None, json=None, enforce_auth=True
     ):
@@ -159,6 +173,12 @@ class Api:
             resource_owner_key=data["oauth_token"],
             resource_owner_secret=data["oauth_token_secret"],
         )
+        if "user_id" in data:
+            self.auth_user_id = data["user_id"]
+        else:
+            self.auth_user_id = self.get_uid_from_access_token_key(
+                access_token=data["oauth_token"]
+            )
         return data
 
     def invalidate_access_token(self) -> dict:
@@ -886,3 +906,37 @@ class Api:
         )
         data = self._parse_response(resp)
         return data
+
+    def like_tweet(self, user_id: str, tweet_id: str) -> dict:
+        """
+        Allows user to like tweet.
+
+        :param user_id: The user ID who you are liking a Tweet on behalf of.
+                It must match your user ID which authorize with the access token.
+        :param tweet_id: The ID of the Tweet that you would like.
+        :return: like status data
+        """
+
+        resp = self._request(
+            url=f"{self.BASE_URL_V2}/users/{user_id}/likes",
+            verb="POST",
+            json={"tweet_id": tweet_id},
+        )
+        data = self._parse_response(resp=resp)
+        return data
+
+    def unlike_tweet(self, user_id: str, tweet_id: str) -> dict:
+        """
+        Allows user to remove like status from a tweet.
+
+        :param user_id: The user ID who you are removing a Like of a Tweet on behalf of.
+                It must match your user ID which authorize with the access token.
+        :param tweet_id: The ID of the Tweet that you would remove like status.
+        :return: like status data
+        """
+
+        resp = self._request(
+            url=f"{self.BASE_URL_V2}/users/{user_id}/likes/{tweet_id}", verb="DELETE"
+        )
+        data = self._parse_response(resp=resp)
+        return data
